@@ -231,8 +231,13 @@ sub _send_emails {
     my ($self, $results) = @_;
 
     # setup some stuff for the emails that we only need to do once
-    my $subject =
-      "[" . $self->project->name . "] new " . ($self->failed ? "failed " : '') . "Smolder report";
+    my $subject = sprintf("Smolder - [%s] %i files ( %i/%i ) : %s",
+                          $self->project->name,
+                          $self->test_files,
+                          $self->pass,
+                          $self->total,
+                          ( $self->failed() ? "FAILURE" : "SUCCESS" ));
+
     my $matrix = Smolder::TAPHTMLMatrix->new(
         smoke_report => $self,
         test_results => $results,
@@ -414,7 +419,7 @@ sub upload_report {
     # send an email to all the user's who want this report
     $report->_send_emails($results);
 
-    # move the tmp file to it's real destination
+    # move the tmp file to its real destination
     my $dest = $report->file;
     my $out_fh;
     if ($file =~ /\.gz$/ or $file =~ /\.zip$/) {
@@ -601,7 +606,7 @@ sub update_from_tap_archive {
     # if they weren't provided during the upload
     if ($meta->{extra_properties}) {
         foreach my $k (keys %{$meta->{extra_properties}}) {
-            foreach my $field qw(architecture platform comments) {
+            foreach my $field (qw(architecture platform comments)) {
                 if (lc($k) eq $field && !$self->get($field)) {
                     $self->set($field => delete $meta->{extra_properties}->{$k});
                     last;
